@@ -3,6 +3,6 @@
 It also contains score collections such as arrays and matrices.
 """
 
-from .base import Score, ErrorScore
+from .base import ErrorScore, Score
 from .complete import *
 from .incomplete import *
